@@ -1,11 +1,10 @@
 #' @useDynLib fs, .registration = TRUE
-#' @importFrom Rcpp sourceCpp
 #' @importFrom methods setOldClass
 NULL
 
 # nocov start
 .onUnload <- function(libpath) {
-  cleanup_()
+  .Call(fs_cleanup_)
   library.dynam.unload("fs", libpath)
 }
 # nocov end
